<template>
  <div ref="dataMenuModal">
    <div
        :class="`${showMenu ? 'translate-x-0 opacity-100 visible ' : 'translate-x-6 opacity-0 invisible' } overflow-hidden z-40 ease-in-out right-16 transform flex flex-col transition-all duration-200  justify-end absolute top-6 bg-white rounded-lg shadow-md min-w-150`">
      <ul class="text-sm text-gray-500 dark:text-gray-300">
        <li v-for="(item, index) in activeItems" :key="`assignment_${index}`">
          <button @click="actionsOnClick(item.id)"
                  class="flex items-center px-3 h-full w-full py-3 text-gray-600 hover:bg-gray-100 overflow-hidden gap-2">
            <span class="relative h-6 w-6" v-html="item.icon"></span>
            <span class="text-sm font-medium" v-if="item.id === 'block'">{{
                isBlocked ? 'Buka Blokir' : 'Blokir'
              }}</span>
            <span class="text-sm font-medium" v-else>{{ item.title }}</span>
          </button>
        </li>
      </ul>
    </div>
    <ModalGeneral ref="modalGeneral" :data="chat.listAgent" header="Tugaskan Agen" :chat-id="chatId"
                  @assign-data="handleAssignEmit" :identitor="'menu_assignment_assign_agent'"/>
    <ModalPromise ref="modalBlock" @onClose="handleBlockClose"
                  @action="handleBlockAction"
                  @onSuccess="handleBlockSuccess" :is-close="closeModalPromise" :message="blockMessage"/>
    <ModalGeneral ref="modalAssignLabel" :add-action="true" :selected-label="labels" type="label" :data="chat.listLabel"
                  header="Contact Label" :chat-id="chatId" @assign-data="handleAssignLabel" :identitor="'menu_assignment_assign_label'"/>
  </div>

</template>
<script setup lang="ts">
import {onBeforeUnmount, onMounted, onUnmounted, ref, watch} from "vue";
import ModalGeneral from "../Modal/ModalGeneral.vue";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";
import useDetectOutsideClick from "../../composable/useDetectOutsideClick";
import helpers from "../../utils/helpers";
import ModalPromise from "../../components/Modal/ModalPromise.vue";
import {message} from "ant-design-vue";
import {useUserStore} from "../../stores/user";

const showMenu = ref(false)
const chat = useChatListStore()
const general = useGeneralStore()
const user = useUserStore()
const agentList = ref([])
const dataMenuModal = ref()
const modalGeneral = ref(false)
const modalBlock = ref(false)
const modalAssignLabel = ref()
const emit = defineEmits(['assignData', 'resolved', 'assignLabel'])

interface Props {
  show?: boolean,
  labels?: any,
  chatId?: number,
  chatDetail?: {
    customer?: {
      user_chat_id?: number
    },
    seller?: {

      user_chat_id?: number
    }
  },
  position?: string
  session?: string
}

let props = withDefaults(defineProps<Props>(), {
  show: false,
  chatDetail: null,
  labels: [],
  chatId: null,
  session: null,
  position: "left"
})

const isBlocked = ref(0)
const chatSession = ref('')
const closeModalPromise = ref(false)


const fetchAssignList = async () => {
  await chat.fetchAgentList()
}

onMounted(async () => {
  await fetchAssignList()
  agentList.value = chat.listAgent
})


const handleAssignEmit = (data) => {
  emit("assignData", data)
}

const handleAssignLabel = (data) => {
  emit("assignLabel", data)
}

const handleBlockClose = (event) => {
  console.log(event, "BLOCK CLOSE")
  modalBlock.value = false
}

const handleBlockAction = async (event) => {
  if (event) {
    if (isBlocked.value) {
      await chat.sendUnblockContact(chat.selectedChat)
          .then((resp) => {
            if (resp?.code === 200) {
              chat.isChatBlocked = 0
              isBlocked.value = 0
              closeModalPromise.value = true
              message.success("Buka Blokir Berhasil")
            }
          })
    } else {
      await chat.sendBlockContact(chat.selectedChat)
          .then((resp) => {
            if (resp?.code === 200) {
              chat.isChatBlocked = 1
              isBlocked.value = 1
              closeModalPromise.value = true
              message.success("Kontak berhasil di blokir")
            }
          })
    }
  }
}

const handleBlockSuccess = (event) => {
  // await chat.sendBlockContact(chat.selectedChat)
  //     .then((resp) => {
  //       emit("action", true)
  //       closeModal()
  //       if (resp?.code === 200) {
  //         chat.isChatBlocked = 1
  //       }
  //     })
  if (event) {

    closeModalPromise.value = false
  }
}

const openModal = (type) => {
  try {
    // noinspection TypeScriptUnresolvedFunction
    if (type === 'block') {
      //@ts-ignore
      modalBlock.value.openModal()
    } else {
      //@ts-ignore
      modalGeneral.value.openModal()
    }
  } catch (e) {
  }
}

const openModalLabel = (type) => {
  try {
    // noinspection TypeScriptUnresolvedFunction
    //@ts-ignore
    modalAssignLabel.value.openModal()
  } catch (e) {
  }
}



const resolvedChat = async () => {
  let type_chat = general.chatTab
  let platform = ''

  if(general.chatTab === 'instagram'){
    if(chat.selectedChatType === 'instagram'){
      platform = 'instagram'
    }
    
    if(chat.selectedChatType === 'facebook'){
      platform = 'page'
    }
  }
  
  const payload = {
    "customer_chat_id": props.chatDetail.customer.user_chat_id,
    "seller_chat_id": props.chatDetail.seller.user_chat_id,
    "platform": platform
  }

  await chat.setResolvedChat(payload,type_chat)
  .then(async (resp) => {

    if(resp == undefined){
      message.error("Pesan tidak dapat diselesaikan, silakan selesaikan proses aktivasi akun Anda.")
    }else{
      emit('resolved', true)
    }

    // await chat.fetchChatListByGroup(chat.tabName)
    // await chat.fetchChatByCustomer(props.chatId)
  })
}

const actionsOnClick = async (event_name) => {
  switch (event_name) {
    case "resolved":
      return await resolvedChat()
    case "assign":
      return openModal("assign")
    case "block":
      return openModal("block")
    case "unblock":
      return openModal("unblock")
    case "label":
      return openModalLabel("assign")
  }
  helpers.logAnalytics("click", {
    event_name: `Klik Action ${event_name}`
  })
}

const activeItems = ref([])
const blockMessage = ref('')

const items = ref([])

if(general.chatTab === 'whatsapp'){
  items.value.push({
    title: "Selesai",
    id: "resolved",
    action: async () => await resolvedChat(),
    icon: `
<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M14.3373 7.23137C14.4474 7.34167 14.5093 7.49117 14.5093 7.64706C14.5093 7.80294 14.4474 7.95245 14.3373 8.06274L8.84706 13.5529C8.73677 13.6631 8.58726 13.725 8.43138 13.725C8.27549 13.725 8.12598 13.6631 8.01569 13.5529L5.66275 11.2C5.55884 11.0885 5.50227 10.941 5.50496 10.7886C5.50765 10.6362 5.56939 10.4908 5.67716 10.383C5.78494 10.2753 5.93034 10.2135 6.08273 10.2108C6.23512 10.2082 6.38261 10.2647 6.49412 10.3686L8.43138 12.3049L13.5059 7.23137C13.6162 7.12121 13.7657 7.05934 13.9216 7.05934C14.0775 7.05934 14.227 7.12121 14.3373 7.23137ZM20 10C20 11.9778 19.4135 13.9112 18.3147 15.5557C17.2159 17.2002 15.6541 18.4819 13.8268 19.2388C11.9996 19.9957 9.98891 20.1937 8.0491 19.8078C6.10929 19.422 4.32746 18.4696 2.92894 17.0711C1.53041 15.6725 0.578004 13.8907 0.192152 11.9509C-0.1937 10.0111 0.00433267 8.00043 0.761209 6.17316C1.51809 4.3459 2.79981 2.78412 4.4443 1.6853C6.08879 0.586489 8.02219 0 10 0C12.6512 0.00311358 15.1929 1.05768 17.0676 2.93237C18.9423 4.80706 19.9969 7.34879 20 10ZM18.8235 10C18.8235 8.25487 18.306 6.54893 17.3365 5.09791C16.367 3.64689 14.9889 2.51595 13.3766 1.84812C11.7643 1.18029 9.99021 1.00555 8.27862 1.34601C6.56702 1.68647 4.99482 2.52683 3.76083 3.76082C2.52683 4.99481 1.68647 6.56702 1.34602 8.27861C1.00556 9.99021 1.18029 11.7643 1.84813 13.3766C2.51596 14.9889 3.64689 16.367 5.09791 17.3365C6.54893 18.306 8.25487 18.8235 10 18.8235C12.3394 18.8209 14.5821 17.8905 16.2363 16.2363C17.8905 14.5821 18.8209 12.3393 18.8235 10Z" fill="#4F46E5"/>
</svg>
`
  })

  items.value.push({
    title: "Tugaskan",
    id: "assign",
    action: () => openModal("assign"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M8.79811 13.2897C9.66857 12.7963 10.3513 12.0287 10.7397 11.1066C11.1281 10.1845 11.2003 9.15977 10.9452 8.19228C10.6901 7.22479 10.1219 6.36894 9.32932 5.75826C8.53673 5.14758 7.5643 4.81641 6.56373 4.81641C5.56317 4.81641 4.59074 5.14758 3.79815 5.75826C3.00556 6.36894 2.43738 7.22479 2.18226 8.19228C1.92713 9.15977 1.99941 10.1845 2.38781 11.1066C2.77621 12.0287 3.45889 12.7963 4.32936 13.2897C2.71606 13.804 1.33056 14.861 0.408264 16.2811C0.340302 16.3852 0.316485 16.5121 0.342051 16.6338C0.367618 16.7554 0.440474 16.862 0.544592 16.9299C0.64871 16.9979 0.775562 17.0217 0.89724 16.9962C1.01892 16.9706 1.12546 16.8977 1.19342 16.7936C1.77515 15.8992 2.57105 15.1642 3.50889 14.6555C4.44672 14.1467 5.49678 13.8802 6.56373 13.8802C7.63069 13.8802 8.68074 14.1467 9.61858 14.6555C10.5564 15.1642 11.3523 15.8992 11.934 16.7936C12.0064 16.8864 12.1111 16.9485 12.2272 16.9677C12.3433 16.9869 12.4623 16.9617 12.5607 16.8972C12.6591 16.8327 12.7296 16.7335 12.7583 16.6193C12.7869 16.5052 12.7716 16.3845 12.7153 16.2811C11.794 14.8617 10.41 13.8048 8.79811 13.2897ZM2.96998 9.34987C2.96998 8.63909 3.18075 7.94428 3.57564 7.35329C3.97052 6.7623 4.53179 6.30168 5.18846 6.02968C5.84514 5.75767 6.56772 5.6865 7.26484 5.82517C7.96196 5.96384 8.6023 6.30611 9.1049 6.8087C9.60749 7.3113 9.94976 7.95164 10.0884 8.64876C10.2271 9.34588 10.1559 10.0685 9.88392 10.7251C9.61192 11.3818 9.1513 11.9431 8.56031 12.338C7.96932 12.7328 7.27451 12.9436 6.56373 12.9436C5.61099 12.9424 4.69763 12.5634 4.02394 11.8897C3.35025 11.216 2.97122 10.3026 2.96998 9.34987ZM19.4544 16.928C19.3503 16.9959 19.2236 17.0197 19.102 16.9942C18.9804 16.9687 18.8739 16.896 18.8059 16.7921C18.2252 15.8975 17.4299 15.1626 16.4925 14.6541C15.555 14.1457 14.5052 13.88 13.4387 13.8811C13.3144 13.8811 13.1952 13.8317 13.1073 13.7438C13.0194 13.6559 12.97 13.5367 12.97 13.4124C12.97 13.288 13.0194 13.1688 13.1073 13.0809C13.1952 12.993 13.3144 12.9436 13.4387 12.9436C13.9679 12.9431 14.4905 12.8257 14.9691 12.5998C15.4476 12.3739 15.8704 12.0451 16.2072 11.6369C16.544 11.2287 16.7865 10.7511 16.9173 10.2384C17.0481 9.72558 17.0641 9.19023 16.9641 8.67056C16.864 8.1509 16.6505 7.65974 16.3386 7.23217C16.0268 6.80461 15.6244 6.45119 15.1601 6.19718C14.6958 5.94316 14.1812 5.79481 13.653 5.76273C13.1247 5.73065 12.5959 5.81562 12.1044 6.01159C12.0471 6.03503 11.9858 6.04691 11.9239 6.04653C11.8621 6.04616 11.8009 6.03355 11.7439 6.00942C11.6869 5.98529 11.6353 5.95012 11.592 5.90594C11.5487 5.86176 11.5146 5.80945 11.4916 5.75202C11.4686 5.69458 11.4572 5.63317 11.458 5.57131C11.4589 5.50945 11.472 5.44837 11.4966 5.39159C11.5211 5.33482 11.5567 5.28347 11.6012 5.24051C11.6457 5.19754 11.6983 5.16382 11.7559 5.14127C12.8222 4.71617 14.0101 4.7116 15.0796 5.12846C16.1491 5.54533 17.0205 6.35257 17.5179 7.38712C18.0152 8.42166 18.1014 9.60641 17.7589 10.702C17.4165 11.7977 16.6711 12.7225 15.6731 13.2897C17.2864 13.804 18.6719 14.861 19.5942 16.2811C19.6612 16.3855 19.6842 16.5122 19.6579 16.6335C19.6317 16.7547 19.5585 16.8606 19.4544 16.928Z" fill="#4F46E5"/>
</svg>
`
  })

  items.value.push({
    title: "Contact Label",
    id: "label",
    action: () => openModalLabel("label"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<g clip-path="url(#clip0_6022_13923)">
<path d="M18.8992 11.5523L11.1398 3.79297C11.0384 3.6912 10.9179 3.6105 10.7851 3.55553C10.6524 3.50056 10.5101 3.47239 10.3664 3.47266H3.125C3.00068 3.47266 2.88145 3.52204 2.79355 3.60995C2.70564 3.69786 2.65625 3.81709 2.65625 3.94141V11.1828C2.65599 11.3265 2.68415 11.4688 2.73912 11.6015C2.7941 11.7343 2.87479 11.8548 2.97656 11.9563L10.7359 19.7156C10.8375 19.8172 10.9581 19.8978 11.0908 19.9528C11.2235 20.0077 11.3657 20.036 11.5094 20.036C11.653 20.036 11.7953 20.0077 11.928 19.9528C12.0607 19.8978 12.1812 19.8172 12.2828 19.7156L18.8992 13.0992C19.0008 12.9977 19.0814 12.8771 19.1363 12.7444C19.1913 12.6117 19.2196 12.4694 19.2196 12.3258C19.2196 12.1821 19.1913 12.0399 19.1363 11.9072C19.0814 11.7745 19.0008 11.6539 18.8992 11.5523ZM18.2359 12.4359L11.6195 19.0523C11.605 19.0669 11.5878 19.0784 11.5688 19.0863C11.5499 19.0941 11.5295 19.0982 11.509 19.0982C11.4885 19.0982 11.4681 19.0941 11.4492 19.0863C11.4302 19.0784 11.413 19.0669 11.3984 19.0523L3.63985 11.293C3.6105 11.2638 3.59393 11.2242 3.59375 11.1828V4.41016H10.3664C10.4078 4.41033 10.4474 4.42691 10.4766 4.45625L18.2359 12.2148C18.2505 12.2294 18.262 12.2466 18.2699 12.2656C18.2777 12.2845 18.2818 12.3049 18.2818 12.3254C18.2818 12.3459 18.2777 12.3663 18.2699 12.3852C18.262 12.4042 18.2505 12.4214 18.2359 12.4359ZM7.34375 7.37891C7.34375 7.53343 7.29793 7.68447 7.21209 7.81295C7.12624 7.94142 7.00423 8.04156 6.86147 8.10069C6.71872 8.15982 6.56164 8.17529 6.41009 8.14515C6.25854 8.115 6.11933 8.0406 6.01007 7.93134C5.90082 7.82208 5.82641 7.68287 5.79626 7.53132C5.76612 7.37978 5.78159 7.22269 5.84072 7.07994C5.89985 6.93718 5.99999 6.81517 6.12846 6.72932C6.25694 6.64348 6.40799 6.59766 6.5625 6.59766C6.7697 6.59766 6.96842 6.67997 7.11493 6.82648C7.26144 6.97299 7.34375 7.17171 7.34375 7.37891Z" fill="#4F46E5"/>
</g>
<defs>
<clipPath id="clip0_6022_13923">
<rect width="20" height="20" fill="white" transform="translate(0 0.816406)"/>
</clipPath>
</defs>
</svg>
`
  })

  items.value.push({
    title: "Blokir",
    id: "block",
    action: () => openModal("block"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M3.12525 4.00781H14.6463C14.8352 4.0079 15.0208 4.05688 15.1851 4.14998C15.3493 4.24307 15.4867 4.37712 15.5838 4.53906L19.1518 10.4852C19.1956 10.5581 19.2188 10.6415 19.2188 10.7266C19.2188 10.8116 19.1956 10.8951 19.1518 10.968L15.5838 16.9141C15.4867 17.076 15.3493 17.2101 15.1851 17.3031C15.0208 17.3962 14.8352 17.4452 14.6463 17.4453H3.12525C2.83517 17.4453 2.55697 17.3301 2.35185 17.125C2.14673 16.9198 2.0315 16.6416 2.0315 16.3516V5.10156C2.0315 4.81148 2.14673 4.53328 2.35185 4.32816C2.55697 4.12305 2.83517 4.00781 3.12525 4.00781ZM2.969 16.3516C2.969 16.393 2.98546 16.4327 3.01476 16.462C3.04406 16.4914 3.08381 16.5078 3.12525 16.5078H14.6463C14.6735 16.5075 14.7001 16.5002 14.7235 16.4865C14.7469 16.4728 14.7664 16.4532 14.7799 16.4297L18.2034 10.7266L14.7799 5.02344C14.7664 4.99994 14.7469 4.98037 14.7235 4.96667C14.7001 4.95297 14.6735 4.94561 14.6463 4.94531H3.12525C3.08381 4.94531 3.04406 4.96177 3.01476 4.99108C2.98546 5.02038 2.969 5.06012 2.969 5.10156V16.3516ZM7.169 9.18281L8.71275 10.7266L7.169 12.2703C7.12294 12.3132 7.086 12.365 7.06038 12.4225C7.03476 12.48 7.02099 12.542 7.01988 12.605C7.01877 12.6679 7.03034 12.7304 7.05392 12.7888C7.07749 12.8472 7.11259 12.9002 7.1571 12.9447C7.20161 12.9892 7.25463 13.0243 7.313 13.0479C7.37137 13.0715 7.43388 13.083 7.49682 13.0819C7.55976 13.0808 7.62183 13.067 7.67933 13.0414C7.73683 13.0158 7.78858 12.9789 7.8315 12.9328L9.37525 11.3891L10.919 12.9328C11.0079 13.0156 11.1254 13.0607 11.2468 13.0585C11.3683 13.0564 11.4841 13.0072 11.57 12.9213C11.6559 12.8354 11.7051 12.7196 11.7072 12.5981C11.7094 12.4767 11.6643 12.3592 11.5815 12.2703L10.0377 10.7266L11.5815 9.18281C11.6643 9.09395 11.7094 8.97642 11.7072 8.85499C11.7051 8.73355 11.6559 8.61768 11.57 8.5318C11.4841 8.44592 11.3683 8.39672 11.2468 8.39458C11.1254 8.39244 11.0079 8.43751 10.919 8.52031L9.37525 10.0641L7.8315 8.52031C7.74264 8.43751 7.62511 8.39244 7.50367 8.39458C7.38223 8.39672 7.26637 8.44592 7.18048 8.5318C7.0946 8.61768 7.0454 8.73355 7.04326 8.85499C7.04112 8.97642 7.0862 9.09395 7.169 9.18281Z" fill="#4F46E5"/>
</svg>
`
  })
}else if(general.chatTab === 'email'){
  items.value.push({
    title: "Selesai",
    id: "resolved",
    action: async () => await resolvedChat(),
    icon: `
<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M14.3373 7.23137C14.4474 7.34167 14.5093 7.49117 14.5093 7.64706C14.5093 7.80294 14.4474 7.95245 14.3373 8.06274L8.84706 13.5529C8.73677 13.6631 8.58726 13.725 8.43138 13.725C8.27549 13.725 8.12598 13.6631 8.01569 13.5529L5.66275 11.2C5.55884 11.0885 5.50227 10.941 5.50496 10.7886C5.50765 10.6362 5.56939 10.4908 5.67716 10.383C5.78494 10.2753 5.93034 10.2135 6.08273 10.2108C6.23512 10.2082 6.38261 10.2647 6.49412 10.3686L8.43138 12.3049L13.5059 7.23137C13.6162 7.12121 13.7657 7.05934 13.9216 7.05934C14.0775 7.05934 14.227 7.12121 14.3373 7.23137ZM20 10C20 11.9778 19.4135 13.9112 18.3147 15.5557C17.2159 17.2002 15.6541 18.4819 13.8268 19.2388C11.9996 19.9957 9.98891 20.1937 8.0491 19.8078C6.10929 19.422 4.32746 18.4696 2.92894 17.0711C1.53041 15.6725 0.578004 13.8907 0.192152 11.9509C-0.1937 10.0111 0.00433267 8.00043 0.761209 6.17316C1.51809 4.3459 2.79981 2.78412 4.4443 1.6853C6.08879 0.586489 8.02219 0 10 0C12.6512 0.00311358 15.1929 1.05768 17.0676 2.93237C18.9423 4.80706 19.9969 7.34879 20 10ZM18.8235 10C18.8235 8.25487 18.306 6.54893 17.3365 5.09791C16.367 3.64689 14.9889 2.51595 13.3766 1.84812C11.7643 1.18029 9.99021 1.00555 8.27862 1.34601C6.56702 1.68647 4.99482 2.52683 3.76083 3.76082C2.52683 4.99481 1.68647 6.56702 1.34602 8.27861C1.00556 9.99021 1.18029 11.7643 1.84813 13.3766C2.51596 14.9889 3.64689 16.367 5.09791 17.3365C6.54893 18.306 8.25487 18.8235 10 18.8235C12.3394 18.8209 14.5821 17.8905 16.2363 16.2363C17.8905 14.5821 18.8209 12.3393 18.8235 10Z" fill="#4F46E5"/>
</svg>
`
  })

  items.value.push({
    title: "Tugaskan",
    id: "assign",
    action: () => openModal("assign"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M8.79811 13.2897C9.66857 12.7963 10.3513 12.0287 10.7397 11.1066C11.1281 10.1845 11.2003 9.15977 10.9452 8.19228C10.6901 7.22479 10.1219 6.36894 9.32932 5.75826C8.53673 5.14758 7.5643 4.81641 6.56373 4.81641C5.56317 4.81641 4.59074 5.14758 3.79815 5.75826C3.00556 6.36894 2.43738 7.22479 2.18226 8.19228C1.92713 9.15977 1.99941 10.1845 2.38781 11.1066C2.77621 12.0287 3.45889 12.7963 4.32936 13.2897C2.71606 13.804 1.33056 14.861 0.408264 16.2811C0.340302 16.3852 0.316485 16.5121 0.342051 16.6338C0.367618 16.7554 0.440474 16.862 0.544592 16.9299C0.64871 16.9979 0.775562 17.0217 0.89724 16.9962C1.01892 16.9706 1.12546 16.8977 1.19342 16.7936C1.77515 15.8992 2.57105 15.1642 3.50889 14.6555C4.44672 14.1467 5.49678 13.8802 6.56373 13.8802C7.63069 13.8802 8.68074 14.1467 9.61858 14.6555C10.5564 15.1642 11.3523 15.8992 11.934 16.7936C12.0064 16.8864 12.1111 16.9485 12.2272 16.9677C12.3433 16.9869 12.4623 16.9617 12.5607 16.8972C12.6591 16.8327 12.7296 16.7335 12.7583 16.6193C12.7869 16.5052 12.7716 16.3845 12.7153 16.2811C11.794 14.8617 10.41 13.8048 8.79811 13.2897ZM2.96998 9.34987C2.96998 8.63909 3.18075 7.94428 3.57564 7.35329C3.97052 6.7623 4.53179 6.30168 5.18846 6.02968C5.84514 5.75767 6.56772 5.6865 7.26484 5.82517C7.96196 5.96384 8.6023 6.30611 9.1049 6.8087C9.60749 7.3113 9.94976 7.95164 10.0884 8.64876C10.2271 9.34588 10.1559 10.0685 9.88392 10.7251C9.61192 11.3818 9.1513 11.9431 8.56031 12.338C7.96932 12.7328 7.27451 12.9436 6.56373 12.9436C5.61099 12.9424 4.69763 12.5634 4.02394 11.8897C3.35025 11.216 2.97122 10.3026 2.96998 9.34987ZM19.4544 16.928C19.3503 16.9959 19.2236 17.0197 19.102 16.9942C18.9804 16.9687 18.8739 16.896 18.8059 16.7921C18.2252 15.8975 17.4299 15.1626 16.4925 14.6541C15.555 14.1457 14.5052 13.88 13.4387 13.8811C13.3144 13.8811 13.1952 13.8317 13.1073 13.7438C13.0194 13.6559 12.97 13.5367 12.97 13.4124C12.97 13.288 13.0194 13.1688 13.1073 13.0809C13.1952 12.993 13.3144 12.9436 13.4387 12.9436C13.9679 12.9431 14.4905 12.8257 14.9691 12.5998C15.4476 12.3739 15.8704 12.0451 16.2072 11.6369C16.544 11.2287 16.7865 10.7511 16.9173 10.2384C17.0481 9.72558 17.0641 9.19023 16.9641 8.67056C16.864 8.1509 16.6505 7.65974 16.3386 7.23217C16.0268 6.80461 15.6244 6.45119 15.1601 6.19718C14.6958 5.94316 14.1812 5.79481 13.653 5.76273C13.1247 5.73065 12.5959 5.81562 12.1044 6.01159C12.0471 6.03503 11.9858 6.04691 11.9239 6.04653C11.8621 6.04616 11.8009 6.03355 11.7439 6.00942C11.6869 5.98529 11.6353 5.95012 11.592 5.90594C11.5487 5.86176 11.5146 5.80945 11.4916 5.75202C11.4686 5.69458 11.4572 5.63317 11.458 5.57131C11.4589 5.50945 11.472 5.44837 11.4966 5.39159C11.5211 5.33482 11.5567 5.28347 11.6012 5.24051C11.6457 5.19754 11.6983 5.16382 11.7559 5.14127C12.8222 4.71617 14.0101 4.7116 15.0796 5.12846C16.1491 5.54533 17.0205 6.35257 17.5179 7.38712C18.0152 8.42166 18.1014 9.60641 17.7589 10.702C17.4165 11.7977 16.6711 12.7225 15.6731 13.2897C17.2864 13.804 18.6719 14.861 19.5942 16.2811C19.6612 16.3855 19.6842 16.5122 19.6579 16.6335C19.6317 16.7547 19.5585 16.8606 19.4544 16.928Z" fill="#4F46E5"/>
</svg>
`
  })

  items.value.push({
    title: "Contact Label",
    id: "label",
    action: () => openModalLabel("label"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<g clip-path="url(#clip0_6022_13923)">
<path d="M18.8992 11.5523L11.1398 3.79297C11.0384 3.6912 10.9179 3.6105 10.7851 3.55553C10.6524 3.50056 10.5101 3.47239 10.3664 3.47266H3.125C3.00068 3.47266 2.88145 3.52204 2.79355 3.60995C2.70564 3.69786 2.65625 3.81709 2.65625 3.94141V11.1828C2.65599 11.3265 2.68415 11.4688 2.73912 11.6015C2.7941 11.7343 2.87479 11.8548 2.97656 11.9563L10.7359 19.7156C10.8375 19.8172 10.9581 19.8978 11.0908 19.9528C11.2235 20.0077 11.3657 20.036 11.5094 20.036C11.653 20.036 11.7953 20.0077 11.928 19.9528C12.0607 19.8978 12.1812 19.8172 12.2828 19.7156L18.8992 13.0992C19.0008 12.9977 19.0814 12.8771 19.1363 12.7444C19.1913 12.6117 19.2196 12.4694 19.2196 12.3258C19.2196 12.1821 19.1913 12.0399 19.1363 11.9072C19.0814 11.7745 19.0008 11.6539 18.8992 11.5523ZM18.2359 12.4359L11.6195 19.0523C11.605 19.0669 11.5878 19.0784 11.5688 19.0863C11.5499 19.0941 11.5295 19.0982 11.509 19.0982C11.4885 19.0982 11.4681 19.0941 11.4492 19.0863C11.4302 19.0784 11.413 19.0669 11.3984 19.0523L3.63985 11.293C3.6105 11.2638 3.59393 11.2242 3.59375 11.1828V4.41016H10.3664C10.4078 4.41033 10.4474 4.42691 10.4766 4.45625L18.2359 12.2148C18.2505 12.2294 18.262 12.2466 18.2699 12.2656C18.2777 12.2845 18.2818 12.3049 18.2818 12.3254C18.2818 12.3459 18.2777 12.3663 18.2699 12.3852C18.262 12.4042 18.2505 12.4214 18.2359 12.4359ZM7.34375 7.37891C7.34375 7.53343 7.29793 7.68447 7.21209 7.81295C7.12624 7.94142 7.00423 8.04156 6.86147 8.10069C6.71872 8.15982 6.56164 8.17529 6.41009 8.14515C6.25854 8.115 6.11933 8.0406 6.01007 7.93134C5.90082 7.82208 5.82641 7.68287 5.79626 7.53132C5.76612 7.37978 5.78159 7.22269 5.84072 7.07994C5.89985 6.93718 5.99999 6.81517 6.12846 6.72932C6.25694 6.64348 6.40799 6.59766 6.5625 6.59766C6.7697 6.59766 6.96842 6.67997 7.11493 6.82648C7.26144 6.97299 7.34375 7.17171 7.34375 7.37891Z" fill="#4F46E5"/>
</g>
<defs>
<clipPath id="clip0_6022_13923">
<rect width="20" height="20" fill="white" transform="translate(0 0.816406)"/>
</clipPath>
</defs>
</svg>
`
  })
  
}else if(general.chatTab === 'instagram'){
  items.value.push({
    title: "Selesai",
    id: "resolved",
    action: async () => await resolvedChat(),
    icon: `
<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M14.3373 7.23137C14.4474 7.34167 14.5093 7.49117 14.5093 7.64706C14.5093 7.80294 14.4474 7.95245 14.3373 8.06274L8.84706 13.5529C8.73677 13.6631 8.58726 13.725 8.43138 13.725C8.27549 13.725 8.12598 13.6631 8.01569 13.5529L5.66275 11.2C5.55884 11.0885 5.50227 10.941 5.50496 10.7886C5.50765 10.6362 5.56939 10.4908 5.67716 10.383C5.78494 10.2753 5.93034 10.2135 6.08273 10.2108C6.23512 10.2082 6.38261 10.2647 6.49412 10.3686L8.43138 12.3049L13.5059 7.23137C13.6162 7.12121 13.7657 7.05934 13.9216 7.05934C14.0775 7.05934 14.227 7.12121 14.3373 7.23137ZM20 10C20 11.9778 19.4135 13.9112 18.3147 15.5557C17.2159 17.2002 15.6541 18.4819 13.8268 19.2388C11.9996 19.9957 9.98891 20.1937 8.0491 19.8078C6.10929 19.422 4.32746 18.4696 2.92894 17.0711C1.53041 15.6725 0.578004 13.8907 0.192152 11.9509C-0.1937 10.0111 0.00433267 8.00043 0.761209 6.17316C1.51809 4.3459 2.79981 2.78412 4.4443 1.6853C6.08879 0.586489 8.02219 0 10 0C12.6512 0.00311358 15.1929 1.05768 17.0676 2.93237C18.9423 4.80706 19.9969 7.34879 20 10ZM18.8235 10C18.8235 8.25487 18.306 6.54893 17.3365 5.09791C16.367 3.64689 14.9889 2.51595 13.3766 1.84812C11.7643 1.18029 9.99021 1.00555 8.27862 1.34601C6.56702 1.68647 4.99482 2.52683 3.76083 3.76082C2.52683 4.99481 1.68647 6.56702 1.34602 8.27861C1.00556 9.99021 1.18029 11.7643 1.84813 13.3766C2.51596 14.9889 3.64689 16.367 5.09791 17.3365C6.54893 18.306 8.25487 18.8235 10 18.8235C12.3394 18.8209 14.5821 17.8905 16.2363 16.2363C17.8905 14.5821 18.8209 12.3393 18.8235 10Z" fill="#4F46E5"/>
</svg>
`
  })

  items.value.push({
    title: "Tugaskan",
    id: "assign",
    action: () => openModal("assign"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M8.79811 13.2897C9.66857 12.7963 10.3513 12.0287 10.7397 11.1066C11.1281 10.1845 11.2003 9.15977 10.9452 8.19228C10.6901 7.22479 10.1219 6.36894 9.32932 5.75826C8.53673 5.14758 7.5643 4.81641 6.56373 4.81641C5.56317 4.81641 4.59074 5.14758 3.79815 5.75826C3.00556 6.36894 2.43738 7.22479 2.18226 8.19228C1.92713 9.15977 1.99941 10.1845 2.38781 11.1066C2.77621 12.0287 3.45889 12.7963 4.32936 13.2897C2.71606 13.804 1.33056 14.861 0.408264 16.2811C0.340302 16.3852 0.316485 16.5121 0.342051 16.6338C0.367618 16.7554 0.440474 16.862 0.544592 16.9299C0.64871 16.9979 0.775562 17.0217 0.89724 16.9962C1.01892 16.9706 1.12546 16.8977 1.19342 16.7936C1.77515 15.8992 2.57105 15.1642 3.50889 14.6555C4.44672 14.1467 5.49678 13.8802 6.56373 13.8802C7.63069 13.8802 8.68074 14.1467 9.61858 14.6555C10.5564 15.1642 11.3523 15.8992 11.934 16.7936C12.0064 16.8864 12.1111 16.9485 12.2272 16.9677C12.3433 16.9869 12.4623 16.9617 12.5607 16.8972C12.6591 16.8327 12.7296 16.7335 12.7583 16.6193C12.7869 16.5052 12.7716 16.3845 12.7153 16.2811C11.794 14.8617 10.41 13.8048 8.79811 13.2897ZM2.96998 9.34987C2.96998 8.63909 3.18075 7.94428 3.57564 7.35329C3.97052 6.7623 4.53179 6.30168 5.18846 6.02968C5.84514 5.75767 6.56772 5.6865 7.26484 5.82517C7.96196 5.96384 8.6023 6.30611 9.1049 6.8087C9.60749 7.3113 9.94976 7.95164 10.0884 8.64876C10.2271 9.34588 10.1559 10.0685 9.88392 10.7251C9.61192 11.3818 9.1513 11.9431 8.56031 12.338C7.96932 12.7328 7.27451 12.9436 6.56373 12.9436C5.61099 12.9424 4.69763 12.5634 4.02394 11.8897C3.35025 11.216 2.97122 10.3026 2.96998 9.34987ZM19.4544 16.928C19.3503 16.9959 19.2236 17.0197 19.102 16.9942C18.9804 16.9687 18.8739 16.896 18.8059 16.7921C18.2252 15.8975 17.4299 15.1626 16.4925 14.6541C15.555 14.1457 14.5052 13.88 13.4387 13.8811C13.3144 13.8811 13.1952 13.8317 13.1073 13.7438C13.0194 13.6559 12.97 13.5367 12.97 13.4124C12.97 13.288 13.0194 13.1688 13.1073 13.0809C13.1952 12.993 13.3144 12.9436 13.4387 12.9436C13.9679 12.9431 14.4905 12.8257 14.9691 12.5998C15.4476 12.3739 15.8704 12.0451 16.2072 11.6369C16.544 11.2287 16.7865 10.7511 16.9173 10.2384C17.0481 9.72558 17.0641 9.19023 16.9641 8.67056C16.864 8.1509 16.6505 7.65974 16.3386 7.23217C16.0268 6.80461 15.6244 6.45119 15.1601 6.19718C14.6958 5.94316 14.1812 5.79481 13.653 5.76273C13.1247 5.73065 12.5959 5.81562 12.1044 6.01159C12.0471 6.03503 11.9858 6.04691 11.9239 6.04653C11.8621 6.04616 11.8009 6.03355 11.7439 6.00942C11.6869 5.98529 11.6353 5.95012 11.592 5.90594C11.5487 5.86176 11.5146 5.80945 11.4916 5.75202C11.4686 5.69458 11.4572 5.63317 11.458 5.57131C11.4589 5.50945 11.472 5.44837 11.4966 5.39159C11.5211 5.33482 11.5567 5.28347 11.6012 5.24051C11.6457 5.19754 11.6983 5.16382 11.7559 5.14127C12.8222 4.71617 14.0101 4.7116 15.0796 5.12846C16.1491 5.54533 17.0205 6.35257 17.5179 7.38712C18.0152 8.42166 18.1014 9.60641 17.7589 10.702C17.4165 11.7977 16.6711 12.7225 15.6731 13.2897C17.2864 13.804 18.6719 14.861 19.5942 16.2811C19.6612 16.3855 19.6842 16.5122 19.6579 16.6335C19.6317 16.7547 19.5585 16.8606 19.4544 16.928Z" fill="#4F46E5"/>
</svg>
`
  })
  
  items.value.push({
    title: "Contact Label",
    id: "label",
    action: () => openModalLabel("label"),
    icon: `
<svg width="20" height="21" viewBox="0 0 20 21" fill="none" xmlns="http://www.w3.org/2000/svg">
<g clip-path="url(#clip0_6022_13923)">
<path d="M18.8992 11.5523L11.1398 3.79297C11.0384 3.6912 10.9179 3.6105 10.7851 3.55553C10.6524 3.50056 10.5101 3.47239 10.3664 3.47266H3.125C3.00068 3.47266 2.88145 3.52204 2.79355 3.60995C2.70564 3.69786 2.65625 3.81709 2.65625 3.94141V11.1828C2.65599 11.3265 2.68415 11.4688 2.73912 11.6015C2.7941 11.7343 2.87479 11.8548 2.97656 11.9563L10.7359 19.7156C10.8375 19.8172 10.9581 19.8978 11.0908 19.9528C11.2235 20.0077 11.3657 20.036 11.5094 20.036C11.653 20.036 11.7953 20.0077 11.928 19.9528C12.0607 19.8978 12.1812 19.8172 12.2828 19.7156L18.8992 13.0992C19.0008 12.9977 19.0814 12.8771 19.1363 12.7444C19.1913 12.6117 19.2196 12.4694 19.2196 12.3258C19.2196 12.1821 19.1913 12.0399 19.1363 11.9072C19.0814 11.7745 19.0008 11.6539 18.8992 11.5523ZM18.2359 12.4359L11.6195 19.0523C11.605 19.0669 11.5878 19.0784 11.5688 19.0863C11.5499 19.0941 11.5295 19.0982 11.509 19.0982C11.4885 19.0982 11.4681 19.0941 11.4492 19.0863C11.4302 19.0784 11.413 19.0669 11.3984 19.0523L3.63985 11.293C3.6105 11.2638 3.59393 11.2242 3.59375 11.1828V4.41016H10.3664C10.4078 4.41033 10.4474 4.42691 10.4766 4.45625L18.2359 12.2148C18.2505 12.2294 18.262 12.2466 18.2699 12.2656C18.2777 12.2845 18.2818 12.3049 18.2818 12.3254C18.2818 12.3459 18.2777 12.3663 18.2699 12.3852C18.262 12.4042 18.2505 12.4214 18.2359 12.4359ZM7.34375 7.37891C7.34375 7.53343 7.29793 7.68447 7.21209 7.81295C7.12624 7.94142 7.00423 8.04156 6.86147 8.10069C6.71872 8.15982 6.56164 8.17529 6.41009 8.14515C6.25854 8.115 6.11933 8.0406 6.01007 7.93134C5.90082 7.82208 5.82641 7.68287 5.79626 7.53132C5.76612 7.37978 5.78159 7.22269 5.84072 7.07994C5.89985 6.93718 5.99999 6.81517 6.12846 6.72932C6.25694 6.64348 6.40799 6.59766 6.5625 6.59766C6.7697 6.59766 6.96842 6.67997 7.11493 6.82648C7.26144 6.97299 7.34375 7.17171 7.34375 7.37891Z" fill="#4F46E5"/>
</g>
<defs>
<clipPath id="clip0_6022_13923">
<rect width="20" height="20" fill="white" transform="translate(0 0.816406)"/>
</clipPath>
</defs>
</svg>
`
  })

}

const showActiveItems = (val = 0) => {
  let arr = []
  
  items.value.map((item) => {
    if (val) {
      if (item.id !== 'resolved' && item.id !== 'assign') {
        arr.push(item)
      }
      blockMessage.value = 'Apakah Anda yakin ingin buka blokir nomor ini?'
    } else {

      if ((user?.user?.is_agent)) {
        if (user?.user?.is_agent_can_assign == 0) {
          if (item.id !== 'assign'){
            arr.push(item)
          }
        }else{
          arr.push(item)
        }
      } else {

        if ((chatSession.value) === 'RESOLVED') {
          if (item.id !== 'resolved' && item.id !== 'assign') {
            arr.push(item)
          }
        }
        if ((chatSession.value) !== 'RESOLVED') {
          arr.push(item)
        }
      }
      blockMessage.value = 'Apakah Anda yakin ingin blokir nomor ini?'
    }
  })
  activeItems.value = arr
}

watch(() => props.show, (val, oldValue) => {
  if (val !== oldValue) {
    showMenu.value = val
  }
})

watch(() => chat.isChatBlocked, (val, oldValue) => {
  isBlocked.value = val
  showActiveItems(val)
})

watch(() => props.session, (val) => {
  console.log('watching chat session', val)
  chatSession.value = val
  showActiveItems()
})

onMounted(() => {
  showActiveItems()
})
useDetectOutsideClick(dataMenuModal, () => {
  try {

    // noinspection TypeScriptUnresolvedFunction
    //@ts-ignore
    // modalGeneral.value.closeModal()
  } catch (e) {
  }
})


</script>
